@@ -5,6 +5,7 @@ from .._impl import (
     api_rids_AutomaticCheckEvaluationRid as AutomaticCheckEvaluationRid,
     api_rids_ChunkRid as ChunkRid,
     api_rids_ConnectAppRid as ConnectAppRid,
+    api_rids_DataConnectorRid as DataConnectorRid,
     api_rids_DataSourceRid as DataSourceRid,
     api_rids_DatasetRid as DatasetRid,
     api_rids_EdgeSyncSourceRid as EdgeSyncSourceRid,
@@ -27,6 +28,7 @@ __all__ = [
     'AutomaticCheckEvaluationRid',
     'ChunkRid',
     'ConnectAppRid',
+    'DataConnectorRid',
     'DataSourceRid',
     'DatasetRid',
     'EdgeSyncSourceRid',
