@@ -13,6 +13,7 @@ from .._impl import (
     ingest_api_ContainerizedExtractorRid as ContainerizedExtractorRid,
     ingest_api_ContainerizedExtractorService as ContainerizedExtractorService,
     ingest_api_ContainerizedOpts as ContainerizedOpts,
+    ingest_api_CreateIngestJobRequest as CreateIngestJobRequest,
     ingest_api_CsvOpts as CsvOpts,
     ingest_api_CustomTimestamp as CustomTimestamp,
     ingest_api_DataSourceRefName as DataSourceRefName,
@@ -48,6 +49,7 @@ from .._impl import (
     ingest_api_IngestJobRequest as IngestJobRequest,
     ingest_api_IngestJobRequestVisitor as IngestJobRequestVisitor,
     ingest_api_IngestJobRid as IngestJobRid,
+    ingest_api_IngestJobService as IngestJobService,
     ingest_api_IngestJobStatus as IngestJobStatus,
     ingest_api_IngestMcapRequest as IngestMcapRequest,
     ingest_api_IngestMcapResponse as IngestMcapResponse,
@@ -71,6 +73,8 @@ from .._impl import (
     ingest_api_IngestVideoResponse as IngestVideoResponse,
     ingest_api_InitiateMultipartUploadRequest as InitiateMultipartUploadRequest,
     ingest_api_InitiateMultipartUploadResponse as InitiateMultipartUploadResponse,
+    ingest_api_InternalIngestJob as InternalIngestJob,
+    ingest_api_InternalIngestJobService as InternalIngestJobService,
     ingest_api_Iso8601Timestamp as Iso8601Timestamp,
     ingest_api_JournalJsonOpts as JournalJsonOpts,
     ingest_api_JournalTimestampMetadata as JournalTimestampMetadata,
@@ -143,6 +147,7 @@ __all__ = [
     'ContainerizedExtractor',
     'ContainerizedExtractorRid',
     'ContainerizedOpts',
+    'CreateIngestJobRequest',
     'CsvOpts',
     'CustomTimestamp',
     'DataSourceRefName',
@@ -200,6 +205,7 @@ __all__ = [
     'IngestVideoResponse',
     'InitiateMultipartUploadRequest',
     'InitiateMultipartUploadResponse',
+    'InternalIngestJob',
     'Iso8601Timestamp',
     'JournalJsonOpts',
     'JournalTimestampMetadata',
@@ -258,6 +264,8 @@ __all__ = [
     'VideoTimestampManifest',
     'VideoTimestampManifestVisitor',
     'ContainerizedExtractorService',
+    'IngestJobService',
     'IngestService',
+    'InternalIngestJobService',
 ]
 
