@@ -1,33 +1,21 @@
 # coding=utf-8
 from .._impl import (
-    module_ArchiveModuleApplicationRequest as ArchiveModuleApplicationRequest,
-    module_ArchiveModuleApplicationResponse as ArchiveModuleApplicationResponse,
     module_BatchArchiveModulesRequest as BatchArchiveModulesRequest,
     module_BatchArchiveModulesResponse as BatchArchiveModulesResponse,
-    module_BatchGetModuleApplicationsRequest as BatchGetModuleApplicationsRequest,
-    module_BatchGetModuleApplicationsResponse as BatchGetModuleApplicationsResponse,
     module_BatchGetModulesRequest as BatchGetModulesRequest,
     module_BatchUnarchiveModulesRequest as BatchUnarchiveModulesRequest,
     module_BatchUnarchiveModulesResponse as BatchUnarchiveModulesResponse,
-    module_CreateModuleApplicationRequest as CreateModuleApplicationRequest,
-    module_CreateModuleApplicationResponse as CreateModuleApplicationResponse,
     module_CreateModuleRequest as CreateModuleRequest,
-    module_DerivedSeriesMetadata as DerivedSeriesMetadata,
     module_Function as Function,
     module_FunctionNode as FunctionNode,
     module_FunctionNodeVisitor as FunctionNodeVisitor,
     module_FunctionParameter as FunctionParameter,
-    module_GetDerivedSeriesRequest as GetDerivedSeriesRequest,
-    module_GetDerivedSeriesResponse as GetDerivedSeriesResponse,
     module_LatestVersionStrategy as LatestVersionStrategy,
     module_Module as Module,
-    module_ModuleApplication as ModuleApplication,
     module_ModuleMetadata as ModuleMetadata,
-    module_ModuleParameter as ModuleParameter,
     module_ModuleRef as ModuleRef,
     module_ModuleService as ModuleService,
     module_ModuleSummary as ModuleSummary,
-    module_ModuleVariable as ModuleVariable,
     module_ModuleVersion as ModuleVersion,
     module_ModuleVersionDefinition as ModuleVersionDefinition,
     module_ModuleVersionMetadata as ModuleVersionMetadata,
@@ -37,10 +25,6 @@ from .._impl import (
     module_RequestModuleRef as RequestModuleRef,
     module_RequestModuleRefVisitor as RequestModuleRefVisitor,
     module_RequestModuleRidRef as RequestModuleRidRef,
-    module_SearchModuleApplicationsQuery as SearchModuleApplicationsQuery,
-    module_SearchModuleApplicationsQueryVisitor as SearchModuleApplicationsQueryVisitor,
-    module_SearchModuleApplicationsRequest as SearchModuleApplicationsRequest,
-    module_SearchModuleApplicationsResponse as SearchModuleApplicationsResponse,
     module_SearchModulesQuery as SearchModulesQuery,
     module_SearchModulesQueryVisitor as SearchModulesQueryVisitor,
     module_SearchModulesRequest as SearchModulesRequest,
@@ -55,33 +39,21 @@ from .._impl import (
 )
 
 __all__ = [
-    'ArchiveModuleApplicationRequest',
-    'ArchiveModuleApplicationResponse',
     'BatchArchiveModulesRequest',
     'BatchArchiveModulesResponse',
-    'BatchGetModuleApplicationsRequest',
-    'BatchGetModuleApplicationsResponse',
     'BatchGetModulesRequest',
     'BatchUnarchiveModulesRequest',
     'BatchUnarchiveModulesResponse',
-    'CreateModuleApplicationRequest',
-    'CreateModuleApplicationResponse',
     'CreateModuleRequest',
-    'DerivedSeriesMetadata',
     'Function',
     'FunctionNode',
     'FunctionNodeVisitor',
     'FunctionParameter',
-    'GetDerivedSeriesRequest',
-    'GetDerivedSeriesResponse',
     'LatestVersionStrategy',
     'Module',
-    'ModuleApplication',
     'ModuleMetadata',
-    'ModuleParameter',
     'ModuleRef',
     'ModuleSummary',
-    'ModuleVariable',
     'ModuleVersion',
     'ModuleVersionDefinition',
     'ModuleVersionMetadata',
@@ -91,10 +63,6 @@ __all__ = [
     'RequestModuleRef',
     'RequestModuleRefVisitor',
     'RequestModuleRidRef',
-    'SearchModuleApplicationsQuery',
-    'SearchModuleApplicationsQueryVisitor',
-    'SearchModuleApplicationsRequest',
-    'SearchModuleApplicationsResponse',
     'SearchModulesQuery',
     'SearchModulesQueryVisitor',
     'SearchModulesRequest',
