@@ -44,12 +44,20 @@ from .._impl import (
     scout_chartdefinition_api_Figure as Figure,
     scout_chartdefinition_api_FrequencyChartDefinition as FrequencyChartDefinition,
     scout_chartdefinition_api_FrequencyChartDefinitionV1 as FrequencyChartDefinitionV1,
+    scout_chartdefinition_api_FrequencyChartDefinitionV2 as FrequencyChartDefinitionV2,
     scout_chartdefinition_api_FrequencyChartDefinitionVisitor as FrequencyChartDefinitionVisitor,
     scout_chartdefinition_api_FrequencyPlot as FrequencyPlot,
+    scout_chartdefinition_api_FrequencyPlotMultivariate as FrequencyPlotMultivariate,
     scout_chartdefinition_api_FrequencyPlotType as FrequencyPlotType,
+    scout_chartdefinition_api_FrequencyPlotTypeBode as FrequencyPlotTypeBode,
+    scout_chartdefinition_api_FrequencyPlotTypeCpsd as FrequencyPlotTypeCpsd,
     scout_chartdefinition_api_FrequencyPlotTypeFft as FrequencyPlotTypeFft,
+    scout_chartdefinition_api_FrequencyPlotTypeNyquist as FrequencyPlotTypeNyquist,
     scout_chartdefinition_api_FrequencyPlotTypePeriodogram as FrequencyPlotTypePeriodogram,
+    scout_chartdefinition_api_FrequencyPlotTypePsd as FrequencyPlotTypePsd,
     scout_chartdefinition_api_FrequencyPlotTypeVisitor as FrequencyPlotTypeVisitor,
+    scout_chartdefinition_api_FrequencyPlotV2 as FrequencyPlotV2,
+    scout_chartdefinition_api_FrequencyPlotV2Visitor as FrequencyPlotV2Visitor,
     scout_chartdefinition_api_Geo3dCustomModel as Geo3dCustomModel,
     scout_chartdefinition_api_Geo3dDefaultModel as Geo3dDefaultModel,
     scout_chartdefinition_api_Geo3dDefinition as Geo3dDefinition,
@@ -148,6 +156,10 @@ from .._impl import (
     scout_chartdefinition_api_StalenessConfiguration as StalenessConfiguration,
     scout_chartdefinition_api_StalenessVisualisation as StalenessVisualisation,
     scout_chartdefinition_api_StalenessVisualisationVisitor as StalenessVisualisationVisitor,
+    scout_chartdefinition_api_StructCellConfig as StructCellConfig,
+    scout_chartdefinition_api_StructRawVisualisation as StructRawVisualisation,
+    scout_chartdefinition_api_StructVisualisation as StructVisualisation,
+    scout_chartdefinition_api_StructVisualisationVisitor as StructVisualisationVisitor,
     scout_chartdefinition_api_Threshold as Threshold,
     scout_chartdefinition_api_ThresholdDisconnectedValues as ThresholdDisconnectedValues,
     scout_chartdefinition_api_ThresholdLatch as ThresholdLatch,
@@ -243,11 +255,19 @@ __all__ = [
     'FrequencyChartDefinition',
     'FrequencyChartDefinitionVisitor',
     'FrequencyChartDefinitionV1',
+    'FrequencyChartDefinitionV2',
     'FrequencyPlot',
+    'FrequencyPlotMultivariate',
     'FrequencyPlotType',
     'FrequencyPlotTypeVisitor',
+    'FrequencyPlotTypeBode',
+    'FrequencyPlotTypeCpsd',
     'FrequencyPlotTypeFft',
+    'FrequencyPlotTypeNyquist',
     'FrequencyPlotTypePeriodogram',
+    'FrequencyPlotTypePsd',
+    'FrequencyPlotV2',
+    'FrequencyPlotV2Visitor',
     'Geo3dCustomModel',
     'Geo3dDefaultModel',
     'Geo3dDefinition',
@@ -346,6 +366,10 @@ __all__ = [
     'StalenessConfiguration',
     'StalenessVisualisation',
     'StalenessVisualisationVisitor',
+    'StructCellConfig',
+    'StructRawVisualisation',
+    'StructVisualisation',
+    'StructVisualisationVisitor',
     'Threshold',
     'ThresholdDisconnectedValues',
     'ThresholdLatch',
