@@ -148,6 +148,8 @@ from .._impl import (
     scout_compute_api_ExcludeNegativeValues as ExcludeNegativeValues,
     scout_compute_api_ExponentialCurve as ExponentialCurve,
     scout_compute_api_ExponentialResultDetails as ExponentialResultDetails,
+    scout_compute_api_ExtractEnumFromStructSeries as ExtractEnumFromStructSeries,
+    scout_compute_api_ExtractNumericFromStructSeries as ExtractNumericFromStructSeries,
     scout_compute_api_ExtractStructFromStructSeries as ExtractStructFromStructSeries,
     scout_compute_api_Fft as Fft,
     scout_compute_api_FftWindow as FftWindow,
@@ -233,6 +235,7 @@ from .._impl import (
     scout_compute_api_NumericApproximateFilterSeries as NumericApproximateFilterSeries,
     scout_compute_api_NumericBucket as NumericBucket,
     scout_compute_api_NumericConstantResampleInterpolationConfiguration as NumericConstantResampleInterpolationConfiguration,
+    scout_compute_api_NumericDataType as NumericDataType,
     scout_compute_api_NumericFilterTransformationSeries as NumericFilterTransformationSeries,
     scout_compute_api_NumericHistogramBucket as NumericHistogramBucket,
     scout_compute_api_NumericHistogramBucketStrategy as NumericHistogramBucketStrategy,
@@ -546,6 +549,8 @@ __all__ = [
     'ExcludeNegativeValues',
     'ExponentialCurve',
     'ExponentialResultDetails',
+    'ExtractEnumFromStructSeries',
+    'ExtractNumericFromStructSeries',
     'ExtractStructFromStructSeries',
     'Fft',
     'FftWindow',
@@ -631,6 +636,7 @@ __all__ = [
     'NumericApproximateFilterSeries',
     'NumericBucket',
     'NumericConstantResampleInterpolationConfiguration',
+    'NumericDataType',
     'NumericFilterTransformationSeries',
     'NumericHistogramBucket',
     'NumericHistogramBucketStrategy',
