@@ -46,6 +46,8 @@ from .._impl import (
     scout_compute_resolved_api_EnumUnionSeriesNode as EnumUnionSeriesNode,
     scout_compute_resolved_api_EventSearchNode as EventSearchNode,
     scout_compute_resolved_api_ExponentialCurve as ExponentialCurve,
+    scout_compute_resolved_api_ExtractEnumFromStructSeriesNode as ExtractEnumFromStructSeriesNode,
+    scout_compute_resolved_api_ExtractNumericFromStructSeriesNode as ExtractNumericFromStructSeriesNode,
     scout_compute_resolved_api_ExtractStructFromStructSeriesNode as ExtractStructFromStructSeriesNode,
     scout_compute_resolved_api_ExtremaRangesNode as ExtremaRangesNode,
     scout_compute_resolved_api_FftNode as FftNode,
@@ -221,6 +223,8 @@ __all__ = [
     'EnumUnionSeriesNode',
     'EventSearchNode',
     'ExponentialCurve',
+    'ExtractEnumFromStructSeriesNode',
+    'ExtractNumericFromStructSeriesNode',
     'ExtractStructFromStructSeriesNode',
     'ExtremaRangesNode',
     'FftNode',
