@@ -20,6 +20,7 @@ from .._impl import (
     scout_rids_api_NotebookRid as NotebookRid,
     scout_rids_api_PendingReviewAlertState as PendingReviewAlertState,
     scout_rids_api_PropertiesFilter as PropertiesFilter,
+    scout_rids_api_RunRefName as RunRefName,
     scout_rids_api_SavedViewRid as SavedViewRid,
     scout_rids_api_SnapshotRid as SnapshotRid,
     scout_rids_api_TemplateRid as TemplateRid,
@@ -52,6 +53,7 @@ __all__ = [
     'NotebookRid',
     'PendingReviewAlertState',
     'PropertiesFilter',
+    'RunRefName',
     'SavedViewRid',
     'SnapshotRid',
     'TemplateRid',
